@@ -135,7 +135,8 @@ Please specify something like '?charset=utf8' explicitly.""")
             # the for loop bellow handles table inheritance
             for base in [base for base in bases if Database.BaseModel in base.__bases__]:
                 if not hasattr(base, 'real_type'):
-                    setattr(base, 'real_type', Column('real_type', String(24), nullable = False, index = True))
+                    setattr(base, 'real_type', Column('real_type', String(24), index = True))
+                    #setattr(base, 'real_type', Column('real_type', String(24), nullable = False, index = True))
                 if base.__mapper__.polymorphic_on is None:
                     base.__mapper__.polymorphic_on = base.__table__.c.real_type
                 if base.__mapper__.polymorphic_identity is None:
